#' @title Shiny-App for ReCo (Automatic Text Response Coder)
#' @description This package delivers a shiny-Package of the ReCo software (Automatic Text Response Coder). It can be used to automatically code (e.g., score) text responses from assessments.
#' @details
#' This is the first release of the shiny app. If you find bugs or you have feedback, please report to info@reco.science.
#' Stay tuned and get details on our website: [reco.science](https://www.reco.science/)
#' In the current version, you can only use precomputed semantic spaces.
#'
#' Start the shiny app with one of the following commands:
#' @example recoApp()
#' @example shinyReCoR::recoApp()
recoApp <- function() {
  appDir <- system.file("shinyApps", "shinyReCo", package = "shinyReCoR")
  if(appDir=="") {
    stop("Could not find the Shiny App's directory. Try re-installing `shinyReCoR`.", call. = FALSE)
  }

  shiny::runApp(appDir, display.mode = "normal")
}

.onAttach <- function(libname, pkgname) {
  packageStartupMessage(paste0("This is the first release of a shiny app for ReCo: https://www.reco.science\nPlease report bugs and feedback to info@reco.science\n\nThe demo data can be found here: ", system.file(paste0("response_data/ReCo_Q00_en", ifelse(grepl("UTF-8|utf8", Sys.getlocale()), "-UTF8", "-ANSI"), ".csv"), package = "shinyReCoR"), ifelse("suppressrecoappstartcommandmessage"%in%ls(envir=.GlobalEnv), "", "\n\nYou can start the app with recoApp().")))
  if(!dir.exists(system.file("projects/", package="shinyReCoR"))) { # Create project folder if none exists
    dir.create(file.path(system.file("", package="shinyReCoR"), "projects"))
  }
  if(file.access(system.file("projects/", package="shinyReCoR"))==-1) { # Check whether file permission are adequate
    warning(paste0("\n\n The directory the package has been installed in is not writable: ", system.file(package="shinyReCoR"), "\nPlease check it exists and R(Studio) has permissions to write. Possibly, it can help to run R/RStudio as administrator."))
  }
}


